<?php

namespace Hospital\Appointment\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Hospital\Appointment\Interfaces\AppointmentRepositoryInterface;

class AppointmentPublicController extends BaseController
{
    // use AppointmentWorkflow;

    /**
     * Constructor.
     *
     * @param type \Hospital\Appointment\Interfaces\AppointmentRepositoryInterface $appointment
     *
     * @return type
     */
    public function __construct(AppointmentRepositoryInterface $appointment)
    {
        $this->repository = $appointment;
        parent::__construct();
    }

    /**
     * Show appointment's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $appointments = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$appointment::$appointment.names'))
            ->view('$appointment::public.appointment.index')
            ->data(compact('$appointments'))
            ->output();
    }

    /**
     * Show appointment's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $appointments = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$appointment::$appointment.names'))
            ->view('$appointment::public.appointment.index')
            ->data(compact('$appointments'))
            ->output();
    }

    /**
     * Show appointment.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $appointment = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$appointment->name . trans('$appointment::$appointment.name'))
            ->view('$appointment::public.appointment.show')
            ->data(compact('$appointment'))
            ->output();
    }

}
