<?php

namespace Hospital\Appointment\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hospital\Appointment\Models\Appointment;

class AppointmentPolicy
{

    /**
     * Determine if the given user can view the appointment.
     *
     * @param UserPolicy $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function view(UserPolicy $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.view') && $user->isAdmin()) {
            return true;
        }

        return $appointment->user_id == user_id() && $appointment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a appointment.
     *
     * @param UserPolicy $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('appointment.appointment.create');
    }

    /**
     * Determine if the given user can update the given appointment.
     *
     * @param UserPolicy $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function update(UserPolicy $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.edit') && $user->isAdmin()) {
            return true;
        }

        return $appointment->user_id == user_id() && $appointment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given appointment.
     *
     * @param UserPolicy $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Appointment $appointment)
    {
        return $appointment->user_id == user_id() && $appointment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given appointment.
     *
     * @param UserPolicy $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given appointment.
     *
     * @param UserPolicy $user
     * @param Appointment $appointment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Appointment $appointment)
    {
        if ($user->canDo('appointment.appointment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
